# solve

a small cli tool for ps

---

## install

```bash
git clone https://github.com/ganghe74/solve
cd solve
pip install .
```

## Usage

```bash
solve get boj 1000
solve tc 2 -p 1000
solve run 1000.cpp
solve diff
```
